@@ -101,7 +101,7 @@ void _add_a_piste(gchar *Anom, GtkListStore *Aliststore, Tgrave *Ag)
   Llengthutf8 = format_length(Llennbr);
   Lfullnameutf8 = _UTF8(Anom);
 
-  gtk_list_store_set(Aliststore, &Liter, 0, TYPE_MP3, 1, GAudioIcone, 2, Lnameutf8, 3,
+  gtk_list_store_set(Aliststore, &Liter, 0, TYPE_MP3, 1, get_image("AudioIcon"), 2, Lnameutf8, 3,
                       Llengthutf8, 4, Lfullnameutf8, 5, Anom, 6, Llennbr, -1);
   g_free(Lfullnameutf8); g_free(Llengthutf8); g_free(Lnameutf8); g_free(Lname);
 
@@ -110,16 +110,17 @@ void _add_a_piste(gchar *Anom, GtkListStore *Aliststore, Tgrave *Ag)
 }
 
 /* callback appele pour l'ajout de chaques fichiers */
-void _add_a_file(gchar *Anom, GtkTreeStore *ATreeStore, GtkTreeIter *Aparent, Tgrave *Ag, guint64 *Adatasize)
+gint _add_a_file(gchar *Anom, GtkTreeStore *ATreeStore, GtkTreeIter *Aparent, Tgrave *Ag, guint64 *Adatasize, GtkTreeIter *Aiter)
 {
   GtkTreeIter Liter;
   gchar *LOnlyName;
   struct stat Lfi;
-  DIR *Ldir;
-  struct dirent *Lcurfic;
+  GDir *Lgdir;
+  const gchar *Ldirname;
   gchar *Lfullname;
   gchar *Lonlynameutf8, *Lnomutf8;
   gchar *Lformatsizeutf8;
+  gboolean Lret;
 
   if ((LOnlyName=strrchr(Anom, '/'))) {
     LOnlyName++;
@@ -128,8 +129,8 @@ void _add_a_file(gchar *Anom, GtkTreeStore *ATreeStore, GtkTreeIter *Aparent, Tg
   }
 
   if (stat(Anom, &Lfi) == -1) {
-    _WARN("erreur lecture fichier '%s'", Anom);
-    return;
+    _WARN("erreur lecture fichier '%s' err [%d]", Anom, errno);
+    return errno;
   }
 
   gtk_tree_store_append(ATreeStore, &Liter, Aparent); 
@@ -140,30 +141,33 @@ void _add_a_file(gchar *Anom, GtkTreeStore *ATreeStore, GtkTreeIter *Aparent, Tg
 
     Lonlynameutf8 = _UTF8(LOnlyName);
     Lnomutf8 = _UTF8(Anom);
-    gtk_tree_store_set(ATreeStore, &Liter, 0, TYPE_DIR, 1, GDirIcone, 2, Lonlynameutf8, 3, "", 4, Lnomutf8, 5, LOnlyName, 6, 0, -1);
+    gtk_tree_store_set(ATreeStore, &Liter, 0, TYPE_DIR, 1, get_image("DirIcon"), 2, Lonlynameutf8, 3, "", 4, Lnomutf8, 5, LOnlyName, 6, 0, -1);
     g_free(Lnomutf8);
     g_free(Lonlynameutf8);
 
-    Ldir = opendir(Anom);
-    if (!Ldir) {
+    Lgdir = g_dir_open(Anom, 0, NULL);
+    if (!Lgdir) {
       _WARN("erreur ouverture repertoire '%s'", Anom);
-      return;
+      return errno;
     }
 
-    while ((Lcurfic = readdir(Ldir))) {
-      if (!strcmp(Lcurfic->d_name, ".") || !strcmp(Lcurfic->d_name, "..")) continue;
-        
-      Lfullname = g_strdup_printf("%s/%s", Anom, Lcurfic->d_name);
-      _add_a_file(Lfullname, ATreeStore, &Liter, Ag, Adatasize);
+    while ((Ldirname = g_dir_read_name(Lgdir))) {
+      if (!strcmp(Ldirname, ".") || !strcmp(Ldirname, "..")) continue;
+
+      Lfullname = g_strdup_printf("%s/%s", Anom, Ldirname);
+      Lret = _add_a_file(Lfullname, ATreeStore, &Liter, Ag, Adatasize, NULL);
       g_free(Lfullname);
+
+      if (Lret == ELOOP || Lret == EMLINK) break;
     }
-    closedir(Ldir);
+
+    g_dir_close(Lgdir);
     
   } else {
     Lonlynameutf8 = _UTF8(LOnlyName);
     Lnomutf8 = _UTF8(Anom);
     Lformatsizeutf8 = format_size(Lfi.st_size);
-    gtk_tree_store_set(ATreeStore, &Liter, 0, TYPE_FILE, 1, GFileIcone, 2, Lonlynameutf8,
+    gtk_tree_store_set(ATreeStore, &Liter, 0, TYPE_FILE, 1, get_image("FileIcon"), 2, Lonlynameutf8,
                                            3, Lformatsizeutf8, 4, Lnomutf8, 5, Anom, 6, Lfi.st_size, -1);
     g_free(Lformatsizeutf8);
     g_free(Lnomutf8);
@@ -171,6 +175,10 @@ void _add_a_file(gchar *Anom, GtkTreeStore *ATreeStore, GtkTreeIter *Aparent, Tg
 
     *(Adatasize)=*(Adatasize) + Lfi.st_size;
   }
+
+  if (Aiter) *Aiter = Liter;
+
+  return Lret;
 }
 
 /* creer un repertoire */
@@ -204,7 +212,7 @@ void gtk_data_creerrepertoire(GtkWidget *btn, gpointer Adata)
     if (!Lname || !*Lname) return;
 
     gtk_tree_store_prepend(GTK_TREE_STORE(Ltreemodel), &Liter, &Lparent); 
-    gtk_tree_store_set(GTK_TREE_STORE(Ltreemodel), &Liter, 0, TYPE_DIR, 1, GDirIcone, 2, Lname, 3, "", 4, "", 5, 0, -1);
+    gtk_tree_store_set(GTK_TREE_STORE(Ltreemodel), &Liter, 0, TYPE_DIR, 1, get_image("DirIcon"), 2, Lname, 3, "", 4, "", 5, 0, -1);
 
     /* on developpe pour qu'il soit visible */
     if ((Lpath = gtk_tree_model_get_path(Ltreemodel, &Liter))) {
@@ -541,7 +549,7 @@ void gtk_data_adddirectory(GtkWidget *Abtn, gpointer Adata)
     Lfiles = gtk_file_chooser_get_filenames(GTK_FILE_CHOOSER(Lfilesel));
 	
     for (Lcur = Lfiles; Lcur && Lcur->data; Lcur = Lcur->next) {
-      _add_a_file((gchar *) Lcur->data, (GtkTreeStore *)Ltreemodel, &Liter, Lg, Ldatasize);
+      _add_a_file((gchar *) Lcur->data, (GtkTreeStore *)Ltreemodel, &Liter, Lg, Ldatasize, NULL);
 
     }
     g_slist_free(Lfiles);
@@ -603,7 +611,7 @@ void gtk_data_addfile(GtkWidget *Abtn, gpointer Adata)
 
     Lfiles = gtk_file_chooser_get_filenames(GTK_FILE_CHOOSER(Lfilesel));
     for (Lcur = Lfiles; Lcur && Lcur->data; Lcur = Lcur->next) {
-      _add_a_file((gchar *) Lcur->data, GTK_TREE_STORE(Ltreemodel), &Liter, Lg, Ldatasize);
+      _add_a_file((gchar *) Lcur->data, GTK_TREE_STORE(Ltreemodel), &Liter, Lg, Ldatasize, NULL);
 
     }
     g_slist_free(Lfiles);
@@ -903,7 +911,7 @@ void confirm_fixcd(GtkWidget *Abtn, gpointer Adata)
   GSList *Llmediarequis = g_slist_append(NULL, GINT_TO_POINTER(_MEDIA_CDR + _MEDIA_NOBLANK + _MEDIA_APPENDABLE));
   gboolean Lstatus;
   
-  Lstatus = waiting_for_user(_MEDIA_BLANKORAPPENDABLE, Lg, Llmediarequis, NULL, get_drive_info(Lg, "dstothercombo"));
+  Lstatus = waiting_for_user(_MEDIA_TITLE_BLANKORAPPENDABLE, Lg, Llmediarequis, NULL, get_drive_info(Lg, "dstothercombo"));
   g_slist_free(Llmediarequis);
   
   if (Lstatus==FALSE) return;
@@ -981,7 +989,7 @@ void confirm_erasecdrw(GtkWidget *Abtn, gpointer Adata)
   GtkWidget *Lconfirm;
   GSList *Llmediarequis = g_slist_append(NULL, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_NOBLANK));
   gboolean Lstatus;
-  Lstatus = waiting_for_user(_MEDIA_BLANKORAPPENDABLE, Lg, Llmediarequis, NULL, get_drive_info(Lg, "dstothercombo"));
+  Lstatus = waiting_for_user(_MEDIA_TITLE_BLANKORAPPENDABLE, Lg, Llmediarequis, NULL, get_drive_info(Lg, "dstothercombo"));
   g_slist_free(Llmediarequis);
   
   if (Lstatus==FALSE) return;
@@ -1049,12 +1057,11 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
     Ltxt = _("Do you really want to create an audio cd ?");
     Ltitle = _("Writing audio cd in progress...");
     Ldevicename1 = get_drive_info(Lg, "dstaudiocombo");
-    Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CDR + _MEDIA_BLANK));
-    Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CDR + _MEDIA_APPENDABLE));
-    Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_BLANK));
-    Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_APPENDABLE));
-    Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_NOBLANK));
-    Lmediatitle1 = _MEDIA_BLANKORAPPENDABLE;
+    Llmediarequis1 = manage_mediarequis(NULL,
+                      _MEDIA_CDR + _MEDIA_BLANK, _MEDIA_CDR + _MEDIA_APPENDABLE,
+                      _MEDIA_CDRW + _MEDIA_BLANK, _MEDIA_CDRW + _MEDIA_APPENDABLE,
+                      _MEDIA_CDRW + _MEDIA_NOBLANK, -1);
+    Lmediatitle1 = _MEDIA_TITLE_BLANKORAPPENDABLE;
   } else if (g_str_has_prefix(Lname, "btnburndata") || g_str_has_prefix(Lname, "btnburndvddata")) {
     GtkTreeIter Liter;
     GtkTreeModel *Ltreemodel = gtk_tree_view_get_model(GTK_TREE_VIEW(sc_grave_get_data(Lg, "_current_list")));
@@ -1089,12 +1096,11 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
       }
       if (!Liso) {
         Ltitle = _("Writing data cd in progress...");
-        Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CDR + _MEDIA_BLANK));
-        Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CDR + _MEDIA_APPENDABLE));
-        Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_BLANK));
-        Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_APPENDABLE));
-        Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_NOBLANK));
-        Lmediatitle1 = _MEDIA_BLANKORAPPENDABLE;
+        Llmediarequis1 = manage_mediarequis(NULL,
+                    _MEDIA_CDR + _MEDIA_BLANK, _MEDIA_CDR + _MEDIA_APPENDABLE,
+                    _MEDIA_CDRW + _MEDIA_BLANK, _MEDIA_CDRW + _MEDIA_APPENDABLE,
+                    _MEDIA_CDRW + _MEDIA_NOBLANK, -1);
+        Lmediatitle1 = _MEDIA_TITLE_BLANKORAPPENDABLE;
       } else {
         Ltitle = _("Writing iso image in progress...");
       }
@@ -1104,11 +1110,12 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
       if (!Liso) {
         Ltxt = _("Do you really want to create a data dvd ?");
         Ltitle = _("Writing data dvd in progress...");
-        Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_DVDR + _MEDIA_BLANK));
-        Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_DVDR + _MEDIA_APPENDABLE));
-        Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_DVDPRW));
-        Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_DVDMRW));
-        Lmediatitle1 = _MEDIA_DVDRew;
+      
+        Llmediarequis1 = manage_mediarequis(NULL,
+                    _MEDIA_DVDR_P + _MEDIA_BLANK, _MEDIA_DVDR_P + _MEDIA_APPENDABLE,
+                    _MEDIA_DVDR_M + _MEDIA_BLANK, _MEDIA_DVDR_M + _MEDIA_APPENDABLE,
+                    _MEDIA_DVD_RAM, _MEDIA_DVDP_RW, _MEDIA_DVDM_RW, -1);
+        Lmediatitle1 = _MEDIA_TITLE_DVDRew;
       } else {
         /* creation image iso */
         Loperation = WRITE_CD;
@@ -1123,18 +1130,18 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
     Ldevicename1 = get_drive_info(Lg, "srccopycombo");
     Liso = !Ldevicename1;
     if (!Liso) {
-      Llmediarequis1 = g_slist_append(Llmediarequis1, GINT_TO_POINTER(_MEDIA_CD + _MEDIA_NOBLANK));
+      Llmediarequis1 = manage_mediarequis(NULL, _MEDIA_CD + _MEDIA_NOBLANK, -1);
       Lmediatitle1 = _MEDIA_CD;
     }
     Ldevicename2 = get_drive_info(Lg, "dstcopycombo");
 
     if (Ldevicename2) {
-      Llmediarequis2 = g_slist_append(Llmediarequis2, GINT_TO_POINTER(_MEDIA_CDR + _MEDIA_BLANK));
-      Llmediarequis2 = g_slist_append(Llmediarequis2, GINT_TO_POINTER(_MEDIA_CDR + _MEDIA_APPENDABLE));
-      Llmediarequis2 = g_slist_append(Llmediarequis2, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_BLANK));
-      Llmediarequis2 = g_slist_append(Llmediarequis2, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_APPENDABLE));
-      Llmediarequis2 = g_slist_append(Llmediarequis2, GINT_TO_POINTER(_MEDIA_CDRW + _MEDIA_NOBLANK));
-      Lmediatitle2 = _MEDIA_BLANKORAPPENDABLE;
+      Llmediarequis2 = manage_mediarequis(NULL, 
+                  _MEDIA_CDR + _MEDIA_BLANK, _MEDIA_CDR + _MEDIA_APPENDABLE,
+                  _MEDIA_CDRW + _MEDIA_BLANK, _MEDIA_CDRW + _MEDIA_APPENDABLE,
+                  _MEDIA_CDRW + _MEDIA_NOBLANK, -1);
+
+      Lmediatitle2 = _MEDIA_TITLE_BLANKORAPPENDABLE;
     }
   }
 
@@ -1176,7 +1183,17 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
 
     gtk_widget_destroy(Lconfirm);
 
+    sc_grave_set_data(Lg, Llmediarequis1, "mediarequis1");
+    sc_grave_set_data(Lg, &Lmediatitle1, "mediatitle1");
+    sc_grave_set_data(Lg, Llmediarequis2, "mediarequis2");
+    sc_grave_set_data(Lg, &Lmediatitle2, "mediatitle2");
+    sc_grave_set_data(Lg, Ltxt, "medialabel");
     show_graverwindow(Lg, (gchar *)Lname, Ltitle);
+    sc_grave_del_data(Lg, "medialabel");
+    sc_grave_del_data(Lg, "mediatitle2");
+    sc_grave_del_data(Lg, "mediarequis2");
+    sc_grave_del_data(Lg, "mediatitle1");
+    sc_grave_del_data(Lg, "mediarequis1");
 
     if (Loperation != WRITE_DVD) {
       sc_grave_del_data(Lg, "useautoblank");
@@ -1188,6 +1205,9 @@ void confirm_burn (GtkWidget *Abtn, gpointer Adata)
     gtk_widget_destroy(Lconfirm);
   }
 
+  g_slist_free(Llmediarequis2);
+  g_slist_free(Llmediarequis1);
+
   sc_grave_destroy(Ldialoghash);
 }
 
@@ -1454,6 +1474,9 @@ void menu_active_proprietes(GtkWidget *Amenuitem, gpointer Adata)
   GtkWidget *Lptr;
   TProgRequis *Lcurentry;
   gchar Ltmp[256];
+  gboolean Lval;
+
+  sc_tooltips(Lwinproprietes, conf_get_boolean("tooltips"));
 
   gtk_dialog_run(GTK_DIALOG(Lwinproprietes));
 
@@ -1476,7 +1499,14 @@ void menu_active_proprietes(GtkWidget *Amenuitem, gpointer Adata)
   conf_store_value("saveconfig", _BOOLEAN_CONF(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Lptr))));
   Lptr = sc_grave_get_widget(Ldialoghash, "inputcharset");
   conf_store_value("charsetdata", get_combo_value_pos(Lptr, 2));
+  Lptr = sc_grave_get_widget(Ldialoghash, "themelist");
+  conf_store_value("theme", get_combo_value_pos(Lptr, 3));
 
+  /* tooltips ! */
+  Lptr = sc_grave_get_widget(Ldialoghash, "tooltips");
+  Lval = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(Lptr));
+  conf_store_value("tooltips", _BOOLEAN_CONF(Lval));
+  sc_tooltips(Lparent, Lval);
 
 #if 0  
   Lptr = sc_grave_get_widget(Ldialoghash, "extended");
@@ -1616,6 +1646,13 @@ void abort_encours(GtkWidget *Abtn, gpointer Adata)
   Tgrave *Lg = (Tgrave *)Adata;
   gint *Lcont = (gint *)sc_grave_get_data(Lg, "cont");
   gboolean *Labort = (gboolean *)sc_grave_get_data(Lg, "gabort");
+  gint *Lpid = (gint *)sc_grave_get_data(Lg, "pid");
+printf(" on va kill !\n");
+  if (*Lpid) {
+    /* on envoi un TERM au process (cdrecord...) pour qu'il s'arrete ! */
+_DEB("kill de %d\n", *Lpid);
+    kill(*Lpid, SIGINT);
+  }
 
   (*Labort) = TRUE;
   (*Lcont) = 1; /* on passe Lcont de 2 a 1 */
@@ -1772,10 +1809,10 @@ void data_dnd_data_received (GtkWidget *Aliste, GdkDragContext *Acontext, gint A
     gint i;
     gchar **Lallname = g_strsplit(Aseldata->data, "\n", 0);
     gchar *Lfilename = NULL;
-    GtkTreeIter Liter;
+    GtkTreeIter Liter, Lfirstiter;
     GtkTreePath *Lpath = NULL;
 
-    gtk_tree_view_get_cursor(GTK_TREE_VIEW(Aliste), &Lpath, NULL);
+    gtk_tree_view_get_dest_row_at_pos(GTK_TREE_VIEW(Aliste), Ax, Ay, &Lpath, NULL); 
     if (!Lpath) {
       if (!gtk_tree_model_get_iter_first(Ltreemodel, &Liter)) {
         gtk_drag_finish (Acontext, FALSE, FALSE, Atime);
@@ -1791,7 +1828,8 @@ void data_dnd_data_received (GtkWidget *Aliste, GdkDragContext *Acontext, gint A
       if (g_ascii_strncasecmp(Lunfic, "file://", 7)) continue;
       if (!(Lfilename = g_filename_from_uri(Lunfic, NULL, NULL))) continue;
 
-      _add_a_file(Lfilename, GTK_TREE_STORE(Ltreemodel), &Liter, Lg, Ldatasize);
+      _add_a_file(Lfilename, GTK_TREE_STORE(Ltreemodel), &Liter, Lg, Ldatasize,
+          i == 0 ? &Lfirstiter : NULL);
       
       g_free(Lfilename);
     }
@@ -1799,8 +1837,10 @@ void data_dnd_data_received (GtkWidget *Aliste, GdkDragContext *Acontext, gint A
     g_strfreev(Lallname);
 
     /* expand element ajoute */
-    if ((Lpath = gtk_tree_model_get_path(Ltreemodel, &Liter))) {
-      gtk_tree_view_expand_row(GTK_TREE_VIEW(Aliste), Lpath, TRUE);
+    if ((Lpath = gtk_tree_model_get_path(Ltreemodel, &Lfirstiter))) {
+      gtk_tree_view_expand_to_path(GTK_TREE_VIEW(Aliste), Lpath);
+      gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(Aliste), Lpath, NULL, FALSE, 0, 0);
+      gtk_tree_view_set_cursor(GTK_TREE_VIEW(Aliste), Lpath, NULL, TRUE);
       gtk_tree_path_free(Lpath);
     }
 
@@ -1828,8 +1868,12 @@ void data_dnd_data_received (GtkWidget *Aliste, GdkDragContext *Acontext, gint A
         
         gtk_tree_model_get_iter(Ltreemodel, &Litersrc, Lpathsrc);
         gtk_tree_model_get_iter(Ltreemodel, &Literdst, Lpathdst);
+
         gtk_tree_model_get(Ltreemodel, &Literdst, 0, &Ltype, -1);
-       
+     
+        /* on ne deplace pas le CD root */ 
+        if (Ltype == TYPE_CD) return;
+
         if (Ltype == TYPE_FILE) {
           gtk_tree_store_insert_after(GTK_TREE_STORE(Ltreemodel), &Liternew, NULL, &Literdst);
         } else {
@@ -2009,7 +2053,7 @@ void menu_start_new(GtkMenuItem *Amenuitem, gpointer Adata)
     gtk_tree_store_clear(GTK_TREE_STORE(Ltreemodel));
     /* icone de base dans la liste des fichiers */
     gtk_tree_store_append(GTK_TREE_STORE(Ltreemodel), &Liter, NULL);
-    gtk_tree_store_set(GTK_TREE_STORE(Ltreemodel), &Liter, 0, TYPE_CD, 1, GCDpetiteIcone, 2,
+    gtk_tree_store_set(GTK_TREE_STORE(Ltreemodel), &Liter, 0, TYPE_CD, 1, get_image("CDsmallIcon"), 2,
         !strcmp(Lname, "bodycddata") ? _("New CD") : _("New DVD"), 3, "", 4, "", 5, 0, -1);
     gtk_tree_view_columns_autosize(Lliste); 
     switch_pbar_status(Lcontenance, *Ldatamaxsize, *Ldatasize, PB_UPDATE_DATA);
