@@ -346,7 +346,7 @@ void remplirelistecharset(GtkListStore *Adata, gboolean Aadddef)
     /* ajout premiere ligne "default" */
     gtk_list_store_append(Adata, &Liter);
 
-    gtk_list_store_set(Adata, &Liter, 0, -1, 1, GcharsetpetiteIcone, 2,
+    gtk_list_store_set(Adata, &Liter, 0, -1, 1, get_image("CharsetSmallIcon"), 2,
           "DEFAULT", 3, _("Use default character set"), -1);
   }
 
@@ -355,7 +355,7 @@ void remplirelistecharset(GtkListStore *Adata, gboolean Aadddef)
 
     gtk_list_store_append(Adata, &Liter);
 
-    gtk_list_store_set(Adata, &Liter, 0, i, 1, GcharsetpetiteIcone, 2,
+    gtk_list_store_set(Adata, &Liter, 0, i, 1, get_image("CharsetSmallIcon"), 2,
           Lptr->data, 3, Lptr->label, -1);
   }
 }
