@@ -249,7 +249,7 @@ void remplirecombograveur(GtkComboBox *Acombo, gint Aquoi, gchar *Aselvalue)
   
   if (Aquoi & TYPE_ISO) { 
     gtk_list_store_append(Ldata, &Liter);
-    gtk_list_store_set(Ldata, &Liter, 0, NULL, 1, GISOpetiteIcone, 2, _("ISO file..."), 3, -1, -1);
+    gtk_list_store_set(Ldata, &Liter, 0, NULL, 1, get_image("ISOsmallIcon"), 2, _("ISO file..."), 3, -1, -1);
 
     if (Aselvalue && Lselok==FALSE && !strcmp(Aselvalue, "iso")) {
       gtk_combo_box_set_active_iter(Acombo, &Liter); 
@@ -626,6 +626,8 @@ Tgrave *manage_main_window (guint64 *Aaudiolen, guint64 *Aaudiomaxlen,
   Lmainbody = GTK_HBOX(sc_grave_get_widget(Lg, "mainbody"));
   Lwindow = GTK_WIDGET(sc_grave_get_widget(Lg, "topwindow"));
 
+  sc_tooltips(Lwindow, conf_get_boolean("tooltips"));
+
   sc_grave_set_data(Lg, Lwindow, "window");
   sc_grave_set_data(Lg, Aaudiolen, "audiolen");
   sc_grave_set_data(Lg, Aaudiomaxlen, "audiomaxlen");
@@ -1141,18 +1143,31 @@ void show_graverwindow (Tgrave *Ag, gchar *Aaction, gchar *Atitle)
   GtkWidget *Lstatusbox = NULL;
   GtkWidget *Lparent = GTK_WIDGET(sc_grave_get_widget(Ag, "topwindow"));
   GError *Lerror = NULL;
+  Tmng *Lmnglogo = gtk_mng_read_file(get_animation("Working"));
+  GtkMngView *Lmngview = GTK_MNG_VIEW(gtk_mng_view_new());
 
   g_assert(Lburng);
+  g_assert(Lmnglogo);
 
   Lwindowburn = sc_grave_get_widget(Lburng, "window_burn"); 
   gtk_window_set_transient_for(GTK_WINDOW(Lwindowburn), GTK_WINDOW(Lparent));
 
+  /* on insere le logo anim mng */
+
+  gtk_mng_free(Lmnglogo);
+  gtk_table_attach(GTK_TABLE(sc_grave_get_widget(Lburng, "tableburn")),
+                   GTK_WIDGET(Lmngview), 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
+  gtk_mng_view_load(Lmngview, Lmnglogo);
+  gtk_widget_show(GTK_WIDGET(Lmngview));
+
+
   /* barres de progression */
   Lpbtotal = GTK_PROGRESS_BAR(sc_grave_get_widget(Lburng, "pb_total"));
   Lpbstep = GTK_PROGRESS_BAR(sc_grave_get_widget(Lburng, "pb_step"));
 
   /* pour la conversion des fichiers audio et la pulse bar */
   Lpbfifo = GTK_PROGRESS_BAR(sc_grave_get_widget(Lburng, "pb_fifo"));
+
   Lpbbuffer = GTK_PROGRESS_BAR(sc_grave_get_widget(Lburng, "pb_buffer"));
   Ltitle = GTK_LABEL(sc_grave_get_widget(Lburng, "gravetitle"));
 
@@ -1224,6 +1239,7 @@ void show_graverwindow (Tgrave *Ag, gchar *Aaction, gchar *Atitle)
   }
 
   if (Lstatusbox) {
+    gtk_mng_view_stop_animation(Lmngview);
     gtk_dialog_run(GTK_DIALOG(Lstatusbox));
     gtk_widget_destroy(Lstatusbox);
   }
@@ -1386,21 +1402,21 @@ void manage_interface(Tgrave *Ag, gint Aaction)
   prepare_menu_images(Ag);
 
   gtk_list_store_append(Lmodel, &Liter);
-  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdaudio", 1, GMenuAudio, 2, _("Audio CD"), -1);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdaudio", 1, get_image("Menu-Audio-"), 2, _("Audio CD"), -1);
   gtk_tree_selection_select_iter(Lselection, &Liter);
   gtk_toggle_top_menu(Ltopmenu, Ag);
 
   gtk_list_store_append(Lmodel, &Liter);
-  gtk_list_store_set(Lmodel, &Liter, 0, "bodycddata", 1, GMenuData, 2, _("Data CD"), -1);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycddata", 1, get_image("Menu-Data-"), 2, _("Data CD"), -1);
 
   gtk_list_store_append(Lmodel, &Liter);
-  gtk_list_store_set(Lmodel, &Liter, 0, "bodydvddata", 1, GMenuDvd, 2, _("Data DVD"), -1);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodydvddata", 1, get_image("Menu-Dvd-"), 2, _("Data DVD"), -1);
 
   gtk_list_store_append(Lmodel, &Liter);
-  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdcopy", 1, GMenuCopy, 2, _("Duplicate CD"), -1);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdcopy", 1, get_image("Menu-Copy-"), 2, _("Duplicate CD"), -1);
 
   gtk_list_store_append(Lmodel, &Liter);
-  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdother", 1, GMenuOther, 2, _("Other operations"), -1);
+  gtk_list_store_set(Lmodel, &Liter, 0, "bodycdother", 1, get_image("Menu-Other-"), 2, _("Other operations"), -1);
  
   gtk_tree_view_columns_autosize(Ltopmenu); 
 
@@ -1572,7 +1588,7 @@ void prepare_listedata(GtkTreeView *Atreedata, gchar *Atitle)
 
   /* icone de base dans la liste des fichiers */
   gtk_tree_store_append(GTK_TREE_STORE(Lmodel), &Liter, NULL);
-  gtk_tree_store_set(Lmodel, &Liter, 0, TYPE_CD, 1, GCDpetiteIcone, 2, Atitle, 3, "", 4, "", 5, "", 6, 0, -1);
+  gtk_tree_store_set(Lmodel, &Liter, 0, TYPE_CD, 1, get_image("CDsmallIcon"), 2, Atitle, 3, "", 4, "", 5, "", 6, 0, -1);
 }
 
 /* fenetre de confirmation avec une checkbox */
