@@ -203,10 +203,11 @@ _DEB("DEBUT COPIE !!");
       Lstatus = FALSE;
     } else {
       sc_grave_set_data(Ag, &Liso, "iso"); /* image iso */
+
       Lstatus = burn_from_image("copy", Ag, Aerror);
+      Lstatus = burn_iso2dvd(Ag, Aerror);
       sc_grave_del_data(Ag, "iso");
     }
-    g_free(Liso);
   } else if (!Lgraveur) {
     /* copie d'un cd vers une image, on utilise readcd */
     struct stat Lfstat;
@@ -230,10 +231,10 @@ _DEB("DEBUT COPIE !!");
           Ltxt, Liso, g_strerror(errno));
       Lstatus = FALSE;
     } else {
+      Ltodo = 1;
       sc_grave_set_data(Ag, &Liso, "iso"); /* image iso */
       Lstatus = make_image(Ag, Aerror);
       sc_grave_del_data(Ag, "iso");
-      g_free(Liso);
     }
   } else {  /* copie d'un cd a un autre, on utilise cdrdao */
     /* on ajoute une tache pour la lecture, 
@@ -360,7 +361,7 @@ gboolean burn_data(Tgrave *Ag, GError **Aerror)
     }
   }
 
-  unlink (Ltmpdir);
+  cleandata(Ag, NULL);
   
   if (Lgraveur && *Liso
       && g_file_test(Liso, G_FILE_TEST_EXISTS + G_FILE_TEST_IS_REGULAR)==TRUE) {
@@ -419,21 +420,21 @@ gboolean burn_audio(Tgrave *Ag, GError **Aerror)
 gboolean deltempdir(gchar *Ldirpath)
 {
   gchar *Lfullname;
-  DIR *Ldir;
-  struct dirent *Lunfic;
+  GDir *Ldir;
+  const gchar *Lunfic;
 
   if (!Ldirpath || !*Ldirpath) return TRUE;
 
-  Ldir = opendir(Ldirpath);
+  Ldir = g_dir_open(Ldirpath, 0, NULL);
   if (!Ldir) {
     g_warning("erreur lors de l'ouverture de [%s]: %s\n", Ldirpath, strerror(errno));
     return FALSE;
   }
 
-  while ((Lunfic = readdir(Ldir))) {
-    if (!strcmp(Lunfic->d_name, ".") || !strcmp(Lunfic->d_name, "..")) continue;
+  while ((Lunfic = g_dir_read_name(Ldir))) {
+    if (!strcmp(Lunfic, ".") || !strcmp(Lunfic, "..")) continue;
 
-    Lfullname = g_strdup_printf("%s/%s", Ldirpath, Lunfic->d_name);
+    Lfullname = g_strdup_printf("%s/%s", Ldirpath, Lunfic);
 
     if (g_file_test(Lfullname, G_FILE_TEST_IS_DIR)) {
       /* on vide le repertoire avant */
@@ -447,7 +448,7 @@ gboolean deltempdir(gchar *Ldirpath)
     g_free(Lfullname);
   }
 
-  closedir(Ldir);
+  g_dir_close(Ldir);
 
   _DEB("on efface => %s\n", Ldirpath);
   if (rmdir(Ldirpath)==-1) {
@@ -516,7 +517,7 @@ gboolean burn_dvddata(Tgrave *Ag, GError **Aerror)
   if (Lgraveur) {
     if (Lsimul) Ltodo++; /* 1 pour la simulation */
 
-    Lstatus = burn_dvd(Ag, Aerror);
+    Lstatus = burn_data2dvd(Ag, Aerror);
   } else {
     Ltmp = _FILENAME(gtk_entry_get_text(Lgraveuriso));
     g_strlcpy(Liso, Ltmp, MAXPATHLEN-1);
@@ -529,7 +530,7 @@ gboolean burn_dvddata(Tgrave *Ag, GError **Aerror)
   sc_grave_del_data(Ag, "extrapara");
   g_free(Lextrapara);
 
-//  unlink(Ltmpdir);
+  cleandata(Ag, NULL);
 
   sc_grave_del_data(Ag, "todo");
   sc_grave_del_data(Ag, "done"); 
@@ -540,39 +541,55 @@ gboolean burn_dvddata(Tgrave *Ag, GError **Aerror)
   return Lstatus;
 }
 
-void set_waitwindow_title(gboolean Ainsert, gint Atypecd, Tgrave *Awaitg)
+gchar* get_media_label(gint Atypecd, gchar *Abuf, gint Alen) {
+  *Abuf = 0;
+
+  if ((Atypecd & _MEDIA_TITLE_BLANKORAPPENDABLE) == _MEDIA_TITLE_BLANKORAPPENDABLE) {
+    g_snprintf(Abuf, Alen, _("an empty or appendable CDR/RW"));
+  } else if (((Atypecd & _MEDIA_DVDP_RW) == _MEDIA_DVDP_RW) || ((Atypecd & _MEDIA_DVDM_RW) == _MEDIA_DVDM_RW)) {
+    g_snprintf(Abuf, Alen, _("a DVDRW"));
+  } else if ((Atypecd & _MEDIA_TITLE_DVDRew) == _MEDIA_TITLE_DVDRew) {
+    g_snprintf(Abuf, Alen, _("an empty or appendable DVDR/RW"));
+  } else if (((Atypecd & _MEDIA_DVDR_P) == _MEDIA_DVDR_P) || ((Atypecd & _MEDIA_DVDR_M) == _MEDIA_DVDR_M)) {
+    g_snprintf(Abuf, Alen, _("a DVDR"));
+  } else if ((Atypecd & _MEDIA_DVD) == _MEDIA_DVD) {
+    g_snprintf(Abuf, Alen, _("a DVD"));
+  } else if ((Atypecd & _MEDIA_CDRW) == _MEDIA_CDRW) {
+    g_snprintf(Abuf, Alen, _("a CDRW"));
+  } else if ((Atypecd & _MEDIA_CDR) == _MEDIA_CDR) {
+    g_snprintf(Abuf, Alen, _("a CDR"));
+  } else if ((Atypecd & _MEDIA_CD) == _MEDIA_CD) {
+    g_snprintf(Abuf, Alen, _("a CD"));
+  } else if (Atypecd == _MEDIA_NONE) {
+    g_snprintf(Abuf, Alen, _("no media"));
+  }
+
+  return Abuf;
+}
+
+void set_waitwindow_title(gboolean Ainsert, gint Atypecd, gint Acurrent, Tgrave *Awaitg)
 {
   gchar Lcd[_BUF_SIZE];
   gchar Ltitle[_BUF_SIZE];
   Tdriveinfo *Ldevice = (Tdriveinfo *)sc_grave_get_data(Awaitg, "device1");
   GtkLabel *Llabel = GTK_LABEL(sc_grave_get_widget(Awaitg, "label1"));
   *Ltitle=0;
-  *Lcd = 0;
-  if (Atypecd & _MEDIA_BLANKORAPPENDABLE) {
-    g_snprintf(Lcd, sizeof(Lcd)-1, _("a CDR/RW"));
-  } else if ((Atypecd & _MEDIA_DVDPRW) || (Atypecd & _MEDIA_DVDMRW)) {
-    g_snprintf(Lcd, sizeof(Lcd)-1, _("a DVDRW"));
-  } else if (Atypecd & _MEDIA_DVDRew) {
-    g_snprintf(Lcd, sizeof(Lcd)-1, _("a DVDR/RW"));
-  } else if (Atypecd & _MEDIA_DVDR) {
-    g_snprintf(Lcd, sizeof(Lcd)-1, _("a DVDR"));
-  } else if (Atypecd & _MEDIA_DVD) {
-    g_snprintf(Lcd, sizeof(Lcd)-1, _("a DVD"));
-  } else if (Atypecd & _MEDIA_CDRW) {
-    g_snprintf(Lcd, sizeof(Lcd)-1, _("a CDRW"));
-  } else if (Atypecd & _MEDIA_CDR) {
-    g_snprintf(Lcd, sizeof(Lcd)-1, _("a CDR"));
-  } else if (Atypecd & _MEDIA_CD) {
-    g_snprintf(Lcd, sizeof(Lcd)-1, _("a CD"));
-  }
+
+  get_media_label(Atypecd, Lcd, sizeof(Lcd)-1);
 
   if (Ainsert) {
     g_snprintf(Ltitle, sizeof(Ltitle)-1, _("Please insert %s in drive %s to continue..."), Lcd, Ldevice->name);
   } else {
     g_snprintf(Ltitle, sizeof(Ltitle)-1, _("Ok there is %s in drive %s."), Lcd, Ldevice->name);
   }
-
   gtk_label_set_text(Llabel, Ltitle);
+
+  if (Ainsert) {
+    Llabel = GTK_LABEL(sc_grave_get_widget(Awaitg, "label2"));
+    g_snprintf(Ltitle, sizeof(Ltitle)-1, _("Currently: %s"),
+        Acurrent > -1 ?  get_media_label(Acurrent, Lcd, sizeof(Lcd)-1) : _("Initialization..."));
+    gtk_label_set_text(Llabel, Ltitle);
+  }
 }
 
 
@@ -585,7 +602,7 @@ gboolean callback_waiting_for_user(gpointer Adata)
   GSList *Lrequis, *Lcur;
   Tdriveinfo *Ldrive = NULL;
   gint *Lmediatitle;
-  gint Lmedialu;
+  gint Lmedialu = _MEDIA_NONE;
   gint Lmediatest;
   gboolean Lstatusmedia = TRUE;
   gboolean *Linitdisp = (gboolean *) sc_grave_get_data(Lg, "initdisp");
@@ -595,31 +612,25 @@ gboolean callback_waiting_for_user(gpointer Adata)
   Lrequis = (GSList *) sc_grave_get_data(Lg, "devicerequis1");
   Ldetect = (gint *) sc_grave_get_data(Lg, "detect1");
   Lmediatitle = (gint *)sc_grave_get_data(Lg, "mediatitle1");
-  Lmedialu = 0;
 
   if (Linitdisp && *Linitdisp) {
-    set_waitwindow_title(Lstatusmedia, *Lmediatitle, Lg);
+    set_waitwindow_title(Lstatusmedia, *Lmediatitle, -1, Lg);
     gtk_widget_show(GTK_WIDGET(sc_grave_get_data(Lg, "window")));
     gdk_flush ();
     *Linitdisp = FALSE;
   }
-    
-/*    if (*Lrequis & _MEDIA_IS_DVD) {*/
+   
+ _DEB("le premier avant le dvd [%d]", Lmedialu); 
   Lmedialu += get_dvdinfo(Lg, Ldrive, NULL);
-/*    }*/
 
-/*    if (*Lrequis & _MEDIA_IS_CD) {*/
-  Lmedialu += get_cdinfo(Lg, Ldrive, NULL);
-/*    }*/
+ _DEB("le deuxieme avant le cd [%d]", Lmedialu); 
+  if (Lmedialu == _MEDIA_NONE) {
+    Lmedialu += get_cdinfo(Lg, Ldrive, NULL);
+  }
 
+ _DEB("[%d] la troisieme apres tout [%d]", Ldetect ? 1 : 0, Lmedialu); 
   if (Ldetect) *Ldetect = Lmedialu;
-/*    Lstatusmedia = (!(_MEDIA_CMP_CD(*Lrequis, Lmedialu) || _MEDIA_CMP_DVD(*Lrequis, Lmedialu))) ||
-                    ((*Lrequis & _MEDIA_BLANKORAPPENDABLE) &&
-                        ((!(Lmedialu  & _MEDIA_BLANK)) && (!(Lmedialu & _MEDIA_APPENDABLE)))) ||
-                     ((*Lrequis & _MEDIA_BLANK) && (Lmedialu & _MEDIA_NOBLANK)) ||
-                     ((*Lrequis & _MEDIA_NOBLANK) && (Lmedialu & _MEDIA_BLANK)) ||
-                     ((*Lrequis & _MEDIA_APPENDABLE) && (!(Lmedialu & _MEDIA_APPENDABLE)));
-    if (Lstatusmedia) LnewCont = TRUE;*/
+
   for (Lcur = Lrequis; Lcur; Lcur = g_slist_next(Lcur)) {
     Lmediatest = (int ) Lcur->data;
     if ((Lmediatest & Lmedialu) == Lmediatest) {
@@ -628,7 +639,7 @@ gboolean callback_waiting_for_user(gpointer Adata)
       break;
     }
   }
-  set_waitwindow_title(Lstatusmedia, *Lmediatitle, Lg);
+  set_waitwindow_title(Lstatusmedia, *Lmediatitle, Lmedialu, Lg);
   gdk_flush ();
 
 
@@ -667,7 +678,7 @@ gboolean waiting_for_user(gint Atitle, Tgrave *Ag, GSList *Arequiscd1, gint *Ade
     sc_grave_set_data(Lwaitg, &Atitle, "mediatitle1");
     sc_grave_set_data(Lwaitg, Arequiscd1, "devicerequis1");
 
-    set_waitwindow_title(TRUE, Atitle, Lwaitg);
+    set_waitwindow_title(TRUE, Atitle, -1, Lwaitg);
   }
 
   gtk_window_set_transient_for(GTK_WINDOW(Lwindow), GTK_WINDOW(Lparent));
@@ -731,6 +742,25 @@ gboolean is_an_iso(Tgrave *Ag, gchar *Aname)
   return Ldrive ? TRUE : FALSE;
 }
 
+/* creation ou ajout de la liste des medias requis */
+GSList *manage_mediarequis(GSList *Acurlist, ...)
+{
+  GSList *Lcurlist = Acurlist ? Acurlist : NULL;
+  va_list Llist;
+  gint Lt;
+
+  va_start(Llist, Acurlist);
+  while (1) {
+    Lt = va_arg(Llist, gint);
+    if (Lt == -1) break;
+
+  Lcurlist = g_slist_append(Lcurlist, GINT_TO_POINTER(Lt));
+  }
+  va_end(Llist);
+
+  return Lcurlist;
+}
+
 /*
  * vim:et:ts=8:sts=2:sw=2
  */
