@@ -198,7 +198,7 @@ gboolean make_iso(Tgrave *Ag, GError **Aerror)
   *Loperationstatus = FALSE;
   gtk_label_set_text(Ltitle, _("Writing image..."));
 
-  Lcommandline = g_strdup_printf("%s %s %s -o %s -graft-points -path-list %s", 
+  Lcommandline = g_strdup_printf("%s %s %s -o %s -graft-points -path-list %s/pathlist", 
       conf_get_string("mkisofs"), Lextrapara, conf_get_string("mkisofspara"), Liso, Ltmpdir);
 
   _DEB("execution [%s]\n", Lcommandline);
