@@ -22,77 +22,15 @@
  *
  */
 
-/* ce code a t a la base gener par glade-2 ! */
-
 #include "graveman.h"
 
 static GdkCursor *_cursor = NULL;
 
-static GList *pixmaps_directories = NULL;
+/* glade-xml.c */
+static const gchar *glade_xml_tooltips_key = "GladeXML::tooltips";
+static GQuark       glade_xml_tooltips_id  = 0;
+/* glade-xml.c */
 
-/* Use this function to set the directory containing installed pixmaps. */
-void add_pixmap_directory (const gchar *Adirectory)
-{
-  pixmaps_directories = g_list_prepend (pixmaps_directories, g_strdup (Adirectory));
-}
-
-/* This is an internally used function to find pixmap files. */
-static gchar* find_pixmap_file (const gchar *Afilename)
-{
-  GList *Lelem;
-
-  /* We step through each of the pixmaps directory to find it. */
-  Lelem = pixmaps_directories;
-  while (Lelem)
-    {
-      gchar *Lpathname = g_strdup_printf ("%s%s%s", (gchar*)Lelem->data,
-                                         G_DIR_SEPARATOR_S, Afilename);
-      if (g_file_test (Lpathname, G_FILE_TEST_EXISTS))
-        return Lpathname;
-      g_free (Lpathname);
-      Lelem = Lelem->next;
-    }
-  return NULL;
-}
-
-/* This is an internally used function to create pixmaps. */
-GtkWidget* create_pixmap (const gchar *Afilename)
-{
-  gchar *Lpathname = NULL;
-  GtkWidget *Lpixmap;
-
-  if (!Afilename || !*Afilename) return gtk_image_new ();
-
-  if (!(Lpathname = find_pixmap_file (Afilename))) {
-    _WARN(_("Image not found: %s"), Afilename);
-    return gtk_image_new ();
-  }
-  Lpixmap = gtk_image_new_from_file (Lpathname);
-  g_free (Lpathname);
-  return Lpixmap;
-}
-
-/* This is an internally used function to create pixmaps. */
-GdkPixbuf* create_pixbuf (const gchar *Afilename)
-{
-  gchar *Lpathname = NULL;
-  GdkPixbuf *Lpixbuf;
-  GError *Lerror = NULL;
-  if (!Afilename || !*Afilename) return NULL;
-
-  if (!(Lpathname = find_pixmap_file (Afilename)))
-  {
-    _WARN(_("Image not found: %s"), Afilename);
-    return NULL;
-  }
-
-  if (!(Lpixbuf = gdk_pixbuf_new_from_file (Lpathname, &Lerror))) {
-    _WARN(_("Cannot load image: %s: %s"), Lpathname, Lerror->message);
-    g_error_free (Lerror);
-  }
-  g_free (Lpathname);
-  return Lpixbuf;
-}
 
 GtkWidget *glade_to_hash(GladeXML *Axml, GHashTable *Ahash, gchar *Akey)
 {
@@ -193,6 +131,7 @@ Tgrave *sc_grave_load(gchar *Aname)
   
   Agrave->xml = glade_xml_new(Lfullname, NULL, NULL);
 
+
   if (!Agrave->xml) {
     g_free(Agrave);
     g_critical(_("error cannot load '%s': %s"), Lfullname, g_strerror(errno));
@@ -204,6 +143,27 @@ Tgrave *sc_grave_load(gchar *Aname)
   return Agrave;
 }
 
+void sc_init()
+{
+  glade_xml_tooltips_id  = g_quark_from_static_string(glade_xml_tooltips_key);
+}
+
+/* activer / desactiver les tooltips */
+void sc_tooltips(GtkWidget *Awin, gboolean Aetat)
+{
+  GtkTooltips *Ltooltips = NULL;
+
+  Ltooltips = GTK_TOOLTIPS(g_object_get_qdata(G_OBJECT(Awin), glade_xml_tooltips_id));
+
+  if (GTK_IS_TOOLTIPS(Ltooltips)) {
+    if (Aetat) {
+      gtk_tooltips_enable(Ltooltips);
+    } else {
+      gtk_tooltips_disable(Ltooltips);
+    }
+  }
+}
+
 Tgrave *sc_grave_destroy(Tgrave *Agrave)
 {
   g_return_val_if_fail(Agrave != NULL, NULL);
